Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::for_each_view< Rng, F > Member List

This is the complete list of members for ranges::v3::for_each_view< Rng, F >, including all inherited members.

back() | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
back() const | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
begin() (defined in ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value >) | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > |
begin() const | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > |
begin_cursor() const (defined in ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value >) | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > | protected
derived() (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > | protected
derived() const | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > | protected
empty() const (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
end() (defined in ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value >) | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > |
end() const | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > |
end_cursor() const (defined in ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value >) | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > | protected
for_each_view()=default (defined in ranges::v3::for_each_view< Rng, F >) | ranges::v3::for_each_view< Rng, F > |
for_each_view(Rng rng, F f) (defined in ranges::v3::for_each_view< Rng, F >) | ranges::v3::for_each_view< Rng, F > |
front() | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
front() const | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
join_view()=default (defined in ranges::v3::join_view< transform_view< Rng, F > >) | ranges::v3::join_view< transform_view< Rng, F > > |
join_view(transform_view< Rng, F > rng, ValRng val) (defined in ranges::v3::join_view< transform_view< Rng, F > >) | ranges::v3::join_view< transform_view< Rng, F > > |
operator bool() const (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > | explicit
operator Container() | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator Container() const | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator!() const (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator=(view_interface &&)=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator=(view_interface const &)=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n]) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n]) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
size() const | ranges::v3::join_view< transform_view< Rng, F > > |
size() const | ranges::v3::join_view< transform_view< Rng, F > > |
size_type typedef (defined in ranges::v3::join_view< transform_view< Rng, F > >) | ranges::v3::join_view< transform_view< Rng, F > > |
view_facade_t typedef (defined in ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value >) | ranges::v3::view_facade< join_view< transform_view< Rng, F >, ValRng >, detail::join_cardinality< transform_view< Rng, F >, ValRng >::value > | protected
view_interface()=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
view_interface(view_interface &&)=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
view_interface(view_interface const &)=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > |
~view_interface()=default (defined in ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality >) | ranges::v3::view_interface< join_view< transform_view< Rng, F >, ValRng >, Cardinality > | protected